from typing import List

from ._PropertyError import PropertyError


class UnionPropertyError(PropertyError):
    def __init__(self, property_name: str, inner_errors: List[PropertyError]):
        super().__init__(property_name, PropertyError.UNKNOWN_ERROR)
        self.inner_errors = inner_errors
